'use strict'
// Fremix Gulpfile
//
// We use this gulpfile to assemble fremix documentation, run unit tests or deploy
// to the relevant online sources such as CDN's
//
// CONTENTS
//  1. Libs | We use one file to import all of our libs
//  2. Shortcuts | For quicker access we create some vars for specific libs
//  3. RequireDir | Loads all the tasks in that dir

// 1. Libraries
var fremix = require(__dirname + "/libs/js/gulp/gulp-fremix");

// 2. Shortcuts
var libs = fremix.libs;
var utils = fremix.utils;
var gulp = libs.gulp;
var gUtils = libs.utils;
var requireDir = libs.requireDir;

var browserSync = require('browser-sync');
var port = process.env.SERVER_PORT || 3000;

// 3. RequireDir to get all our tasks
requireDir(__dirname + "/libs/js/gulp/tasks");

// 4. Vars
var ENV = utils.getEnv();

// Build The documentation
gulp.task('build', ['clean', 'copy', 'sass:docs', 'javascript:docs'])

gulp.task('build:dist', ['sass:fremix', 'javascript:fremix'])

// Starts a BrowerSync instance
gulp.task('serve', ['build'], function(){
    return browserSync.init({server: './build', port: port});
});

// Default Task
gulp.task('help', function(){
    console.log(" Working in " + ENV + " mode");
    return libs.taskListing()
})

gulp.task('watch', ['serve'], function(){
    // Watch Static files
    gulp.watch(['!./docs/*.*','./docs/**/*.*','!./docs/pages/**/*.*','!./docs/assets/{scss,js}/**/*.*'],
        ['copy:static', browserSync.reload]);
    // Watch pages and html
    gulp.watch(['./docs/*.html','./docs/pages/**/*.html',],
        ['copy:pages', browserSync.reload]);
    // Watch scss
    gulp.watch(['./docs/assets/scss/**','libs/scss/**'],
        ['sass:docs', browserSync.reload])
    // Watch Javascript
    gulp.watch(['./libs/js/angular/**/*','./docs/assets/js/**'],
        ['javascript:docs', browserSync.reload])
});

gulp.task('default', ['help'])

